==> pd-iemutils_0.0.20210927.orig.tar.gz: iem_utils-0.0.20210927/iem_adaptfilt/src/iem_adaptfilt.c <==
/* For information on usage and redistribution, and for a DISCLAIMER OF ALL
* WARRANTIES, see the file, "LICENSE.txt," in this distribution.

iem_adaptfilt written by Markus Noisternig & Thomas Musil
noisternig_AT_iem.at; musil_AT_iem.at
(c) Institute of Electronic Music and Acoustics, Graz Austria 2018 */

#ifdef _MSC_VER
#pragma warning( disable : 4305 )  /* uncast const double to float */
#pragma warning( disable : 4244 )  /* uncast float/int conversion etc. */
#pragma warning( disable : 4101 )  /* unused automatic variables */
#endif /* _MSC_VER */


#include "m_pd.h"
#include "iemlib.h"

static t_class *iem_adaptfilt_class;

static void *iem_adaptfilt_new(void)
{
        t_object *x = (t_object *)pd_new(iem_adaptfilt_class);

        return (x);
}

void NLMS_tilde_setup(void);
void NLMSerr_in_tilde_setup(void);
void NLMSCC_tilde_setup(void);
void n_CNLMS_tilde_setup(void);
void n_CLNLMS_tilde_setup(void);
void FXNLMSplus2in_tilde_setup(void);
void FXNLMSplus3in_tilde_setup(void);

/* ------------------------ setup routine ------------------------- */

void iem_adaptfilt_setup(void)
{
  NLMS_tilde_setup();
  NLMSerr_in_tilde_setup();
  NLMSCC_tilde_setup();
  n_CNLMS_tilde_setup();
  n_CLNLMS_tilde_setup();
  FXNLMSplus2in_tilde_setup();
  FXNLMSplus3in_tilde_setup();
  
  post("----------------------------------------------");
  post("iem_adaptfilt (1.03) library loaded!");
  post("   (c) Markus Noisternig, Thomas Musil");
  post("   {noisternig, musil}_AT_iem.at");
  post("   iem KUG Graz Austria, "BUILD_DATE);
  post("----------------------------------------------");
}

==> pd-iemutils_0.0.20240903.orig.tar.gz: iem_utils-0.0.20240903/iem_adaptfilt/src/iem_adaptfilt.c <==
/* For information on usage and redistribution, and for a DISCLAIMER OF ALL
* WARRANTIES, see the file, "LICENSE.txt," in this distribution.

iem_adaptfilt written by Markus Noisternig & Thomas Musil
noisternig_AT_iem.at; musil_AT_iem.at
(c) Institute of Electronic Music and Acoustics, Graz Austria 2018 */

#ifdef _MSC_VER
#pragma warning( disable : 4305 )  /* uncast const double to float */
#pragma warning( disable : 4244 )  /* uncast float/int conversion etc. */
#pragma warning( disable : 4101 )  /* unused automatic variables */
#endif /* _MSC_VER */


#include "m_pd.h"
#include "iemlib.h"

static t_class *iem_adaptfilt_class;

static void *iem_adaptfilt_new(void)
{
  t_object *x = (t_object *)pd_new(iem_adaptfilt_class);
  return (x);
}

void NLMS_tilde_setup(void);
void NLMSerr_in_tilde_setup(void);
void NLMSCC_tilde_setup(void);
void n_CNLMS_tilde_setup(void);
void n_CLNLMS_tilde_setup(void);
void FXNLMSplus2in_tilde_setup(void);
void FXNLMSplus3in_tilde_setup(void);

/* ------------------------ setup routine ------------------------- */

void iem_adaptfilt_setup(void)
{
  NLMS_tilde_setup();
  NLMSerr_in_tilde_setup();
  NLMSCC_tilde_setup();
  n_CNLMS_tilde_setup();
  n_CLNLMS_tilde_setup();
  FXNLMSplus2in_tilde_setup();
  FXNLMSplus3in_tilde_setup();


  iem_adaptfilt_class = class_new(gensym("iem_adaptfilt"),
				  (t_newmethod)iem_adaptfilt_new, 0,
				  sizeof(t_object), 0, A_GIMME, 0);

  post("----------------------------------------------");
  post("iem_adaptfilt (1.03) library loaded!");
  post("   (c) Markus Noisternig, Thomas Musil");
  post("   {noisternig, musil}_AT_iem.at");
  post("   iem KUG Graz Austria, "BUILD_DATE);
  post("----------------------------------------------");
}
